@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Call;
 
-our $DATE = '2016-02-14'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -44,7 +44,7 @@ _
 };
 sub call_cli_script {
     require IPC::System::Options;
-    require JSON;
+    require JSON::MaybeXS;
 
     my %args = @_;
 
@@ -56,7 +56,7 @@ sub call_cli_script {
         $script, "--json", "--no-naked-res", @$argv,
     );
 
-    eval { $res = JSON::decode_json($res) };
+    eval { $res = JSON::MaybeXS::decode_json($res) };
     die if $@;
 
     $res;
@@ -77,7 +77,7 @@ Perinci::CmdLine::Call - "Call" a Perinci::CmdLine-based script
 
 =head1 VERSION
 
-This document describes version 0.04 of Perinci::CmdLine::Call (from Perl distribution Perinci-CmdLine-Call), released on 2016-02-14.
+This document describes version 0.05 of Perinci::CmdLine::Call (from Perl distribution Perinci-CmdLine-Call), released on 2016-03-16.
 
 =head1 SYNOPSIS
 
